@@ -5,8 +5,10 @@ class SecureNativeOptions(object):
 
     def __init__(self, api_key=None, api_url="https://api.securenative.com/collector/api/v1", interval=1000,
                  max_events=1000, timeout=1500, auto_send=True, disable=False, log_level="CRITICAL",
-                 fail_over_strategy=FailOverStrategy.FAIL_OPEN.value):
+                 fail_over_strategy=FailOverStrategy.FAIL_OPEN.value, proxy_headers=None):
 
+        if proxy_headers is None:
+            proxy_headers = []
         if fail_over_strategy != FailOverStrategy.FAIL_OPEN.value and \
                 fail_over_strategy != FailOverStrategy.FAIL_CLOSED.value:
             self.fail_over_strategy = FailOverStrategy.FAIL_OPEN.value
@@ -21,3 +23,4 @@ class SecureNativeOptions(object):
         self.auto_send = auto_send
         self.disable = disable
         self.log_level = log_level
+        self.proxy_headers = proxy_headers
