@@ -1,6 +1,7 @@
 from securenative.api_manager import ApiManager
 from securenative.config.configuration_manager import ConfigurationManager
 from securenative.config.securenative_options import SecureNativeOptions
+from securenative.context.securenative_context import SecureNativeContext
 from securenative.event_manager import EventManager
 from securenative.exceptions.securenative_config_exception import SecureNativeConfigException
 from securenative.exceptions.securenative_sdk_Illegal_state_exception import SecureNativeSDKIllegalStateException
@@ -75,6 +76,9 @@ class SecureNative:
     def _flush(cls):
         cls._securenative = None
 
+    def from_http_request(self, request):
+        return SecureNativeContext.from_http_request(request, self._options)
+
     def verify_request_payload(self, request):
         request_signature = request.header[SignatureUtils.SignatureHeader]
         body = request.body
